addCountsToConstraintData: (Internal) Count number of pool items that match a constraint

View source: R/constraint_functions.R

addCountsToConstraintDataR Documentation

(Internal) Count number of pool items that match a constraint

Description

addCountsToConstraintData is an internal function for counting the number of items in the pool that match a constraint.

Usage

addCountsToConstraintData(x, attrib)

Arguments

x

a data.frame containing a single constraint data.

attrib

an item_attrib object or a st_attrib object.

Value

addCountsToConstraintData returns an updated data.frame.


TestDesign documentation built on Sept. 8, 2026, 9:07 a.m.