assemblyInFinalThetaSegmentWasFeasibleAtLeastOnceInInterimThetaSegments
is an internal function for determining if shadowtest assembly was feasible for exposure control purposes.
Specifically, for the segment k the final theta estimate belonged to,
it returns TRUE if shadowtest assembly was feasible at any interim theta that also belonged to k,
and returns FALSE otherwise.
assemblyInFinalThetaSegmentWasFeasibleAtLeastOnceInInterimThetaSegments(
x,
final_theta_segment
)assemblyInFinalThetaSegmentWasFeasibleAtLeastOnceInInterimThetaSegments
returns TRUE or FALSE.
an output_Shadow object, containing data for a single examinee.
the segment the final theta estimate belonged to.
Example 1:
Interim theta segments are 1, 2, 3, 4, 5, 1, 2, 3, 4, 5
Shadowtest feasibility are 1, 1, 1, 0, 0, 1, 0, 0, 0, 0
Final theta estimate is in segment 3
From the two vectors, segments where shadowtest assembly was feasible: 1, 2, 3, 1
Final theta segment 3 is an element of the above vector. Return TRUE
Example 2:
Interim theta segments are 1, 2, 3, 4, 5, 1, 2, 3, 4, 5
Shadowtest feasibility are 1, 1, 1, 0, 0, 1, 0, 0, 0, 0
Final theta estimate is in segment 4
From the two vectors, segments where shadowtest assembly was feasible: 1, 2, 3, 1
Final theta segment 4 is not an element of the above vector. Return FALSE